=======
History
=======

In Progress
-----------
* Add more meaningful unittests.


0.2.0 (2019-01-14)
------------------

* Improve README - Add usage examples.
* Update the setup.py to point to official PyroBuf 0.8.5 PyPi release.


0.1.0 (2019-01-13)
------------------

* First release on PyPI.
* CLI interface for compiling a given proto file to schematics definition file.
